;-------------------------------------------------------------------------------------------------------------------------
function get_Ap, scenario, year=year, month=month, day=day, doy=doy, julian_day=julian_day, path=path, hourly=hourly
;-------------------------------------------------------------------------------------------------------------------------
; RETURN VALUE
; get_Ap returns the Ap index for all scenarios between
; 1/1/1960 and 31/12/2100
; Ap (float) : daily Ap, if hourly is not set
; Ap (float array, dimension=8) : 3-hourly Ap, if hourly is set
;
; ARGUMENTS:
; scenario      : 'REF' or 'SOLARTREND'
;
; KEYWORDS: 
; year          : actual year
; month         : actual month
; day           : actual day
; doy           : actual day of the year 
; julian_day    : actual Julian day 
; path (string) : directory path of nc files ("./" if empty)
; hourly        : 3-hourly Ap is returned if set
;
  if strupcase(strtrim(scenario,2)) eq 'REF' then cscen='REF' else if $
     strupcase(strtrim(scenario,2)) eq 'SOLARTREND' then cscen='SEN_solar_trend' else begin
     print, 'Error: scenario does not exist'
     stop
  endelse
  if keyword_set(julian_day) then jul=round(julian_day) else begin 
     if keyword_set(doy) then begin
        if not keyword_set(year) then begin
           print, 'Error: year must be given with doy'
           stop
        endif
        jul=julday(1,1,year)+doy-1
     endif else begin
        if not keyword_set(year) and not keyword_set(month) and not keyword_set(day) then begin
           print, 'Error: year, month, day must be given'
           stop
        endif
        jul=julday(month,day,year)
     endelse
  endelse    
  if keyword_set(path) then cpath = path else cpath='' 
  ncf=NCDF_OPEN(strtrim(cpath)+'Ap_'+cscen+'.nc',/NOWRITE)
  ivar=NCDF_VARID(ncf, 'time')
  NCDF_VARGET, ncf, ivar,time
  if keyword_set(hourly) then ivar=NCDF_VARID(ncf, 'Ap_3hourly') else ivar=NCDF_VARID(ncf, 'Ap_daily')
  NCDF_VARGET, ncf, ivar, aap
  NCDF_CLOSE,ncf
  if max(jul) gt max(time)+0.1 or min(jul) lt min(time)-0.1 then begin
     print, 'Error: date not given in file'
     stop
  endif else begin
     ind=value_locate(time,jul)
     ap=aap(ind,*) 
  endelse
  return,ap
end 
